@@ -1,6 +1,37 @@
-import importlib.metadata
+"""
+Fluidsimfoam API reference
 
-from fluidsim_core.params import Parameters
+.. rubric:: Sub-packages
+
+.. autosummary::
+   :toctree:
+
+   foam_input_files
+   solvers
+   output
+   util
+   resources
+
+.. rubric:: Modules
+
+.. autosummary::
+   :toctree:
+
+   info
+   make
+   init_fields
+   operators
+   log
+   tasks
+   testing
+   params
+   next_fluidsim_core
+
+"""
+import importlib.metadata
+import sys
+
+from fluidsimfoam.params import Parameters
 
 from .next_fluidsim_core import path_try_from_fluidsim_path
 
@@ -26,7 +57,11 @@ def load_simul(path_dir="."):
     short_name = get_solver_short_name(path_dir)
     Simul = import_cls_simul(short_name)
 
-    params = Parameters(path_file=path_dir / "params_simul.xml")
+    path_params = path_dir / "params_simul.xml"
+    if not path_params.exists():
+        path_params = path_dir / ".data_fluidsim/params_simul.xml"
+
+    params = Parameters(path_file=path_params)
 
     # Modify parameters prior to loading
     params.NEW_DIR_RESULTS = False
@@ -37,7 +72,7 @@ def load_simul(path_dir="."):
 
 
 def load_params(path_dir="."):
-    """Load a :class:`fluidsim_core.params.Parameters` instance from `path_dir`.
+    """Load a :class:`fluidsim_core.params.Parameters` instance from ``path_dir``
 
     Parameters
     ----------
@@ -54,3 +89,9 @@ def load_params(path_dir="."):
 
 
 load = load_simul
+
+
+if any("pytest" in part for part in sys.argv):
+    import pytest
+
+    pytest.register_assert_rewrite("fluidsimfoam.testing")
